#' A package for computing the repeated measures correlation coefficient
#' 
# @docType package
"_PACKAGE"
#' @keywords internal
#' @name rmcorr-package
#' @description \packageDescription{rmcorr}
#' 
#' @references Bakdash, J.Z. & Marusich, L.R. (2017). 
#' Repeated Measures Correlation, \emph{Frontiers in Psychology, 8}, 456, 
#' \doi{https://doi.org/10.3389/fpsyg.2017.00456}
#' 
#' @references Bakdash, J.Z. & Marusich, L.R. (2019). 
#' Corrigendum: Repeated Measures Correlation, \emph{Frontiers in Psychology, 
#' 10}, \doi{https://doi.org/10.3389/fpsyg.2019.01201}
NULL

# \name{rmcorr-package}
# \alias{rmcorr-package}
# \docType{package}
# \title{
#     \packageTitle{rmcorr}
# }
# \description{
#     \packageDescription{rmcorr}
# }
# \details{
#     
#     The DESCRIPTION file:
#         \packageDESCRIPTION{rmcorr}
#     \packageIndices{rmcorr}
#     
# }
# \author{
#     \packageAuthor{rmcorr}
#     
#     Maintainer: \packageMaintainer{rmcorr}
# }
# \references{
#     ~~ Literature or other references for background information ~~
# }
# 
# \keyword{ package }
# 
# \examples{
#     
# }